<?php
/**
 * @package SNS Product Slider
 * @version 1.0.0
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @copyright (c) 2014 SNS Group. All Rights Reserved.
 * @author SNSGroup http://snstheme.com
 */
if (!defined('_PS_VERSION_'))
	exit ;

include_once(dirname(__FILE__) . '/snsproducttabsclass.php');

class SNSProductTabs extends SNSProductTabsClass {
	public function __construct() {
		$this->name = 'snsproducttabs';
		$this->tab = 'front_office_features';
		$this->version = '1.0';
		$this->author = 'SNS Theme';
		$this->need_instance = 0;
		$this->bootstrap = true;

		parent::__construct();

		$this->displayName = $this->l('SNS Product Tabs');
		$this->description = $this->l('Display products as tabs');
	}
	public function install() {
		if (!parent::install()) return false;
		
		$this->clearCache();
		
		// Activate every option by default
		Configuration::updateValue('SNSPRT_TITLE', 'SNS Product Tabs', true);
		Configuration::updateValue('SNSPRT_NUMDISPLAY', 8);
		Configuration::updateValue('SNSPRT_NUMLOAD', 4);
		Configuration::updateValue('SNSPRT_EFFECT', 'zoomOut');
		Configuration::updateValue('SNSPRT_XS', 2);
		Configuration::updateValue('SNSPRT_SM', 3);
		Configuration::updateValue('SNSPRT_MD', 4);
		Configuration::updateValue('SNSPRT_LG', 4);

		Configuration::updateValue('SNSPRT_CATEGORY_TABS_ID', 'featured_product,special_product,new_product,top_sellers');
		Configuration::updateValue('SNSPRT_CLASSSFX', '');
		Configuration::updateValue('SNSPRT_PRETEXT', '', true);
		Configuration::updateValue('SNSPRT_POSTEXT', '', true);
		
		$this->registerHook('displayHome');
		$this->registerHook('displayHeader');
		$this->registerHook('addproduct');
		$this->registerHook('updateproduct');
		$this->registerHook('deleteproduct');
		
		$this->installFixtures();
		$this->_createTab();
		
		return true;
	}
	protected function installFixtures() {
		$languages = Language::getLanguages(false);
		foreach ($languages as $lang)
			$this->installFixture((int)$lang['id_lang']);
		return true;
	}
	protected function installFixture($id_lang) {
		$values['SNSPRT_TITLE'][(int)$id_lang] = 'SNS Product Tabs';
		$values['SNSPRT_PRETEXT'][(int)$id_lang] = '';
		$values['SNSPRT_POSTEXT'][(int)$id_lang] = '';
		Configuration::updateValue('SNSPRT_TITLE', $values['SNSPRT_TITLE'], true);
		Configuration::updateValue('SNSPRT_PRETEXT', $values['SNSPRT_PRETEXT'], true);
		Configuration::updateValue('SNSPRT_POSTEXT', $values['SNSPRT_POSTEXT'], true);
	}
	public function uninstall() {
		Configuration::deleteByName('SNSPRT_TITLE');
		Configuration::deleteByName('SNSPRT_NUMDISPLAY');
		Configuration::deleteByName('SNSPRT_NUMLOAD');
		Configuration::deleteByName('SNSPRT_EFFECT');
		Configuration::deleteByName('SNSPRT_XS');
		Configuration::deleteByName('SNSPRT_SM');
		Configuration::deleteByName('SNSPRT_MD');
		Configuration::deleteByName('SNSPRT_LG');
		Configuration::deleteByName('SNSPRT_CATEGORY_TABS_ID');
		Configuration::deleteByName('SNSPRT_CLASSSFX');
		Configuration::deleteByName('SNSPRT_PRETEXT');
		Configuration::deleteByName('SNSPRT_POSTEXT');
		$this->_deleteTab();
		return parent::uninstall();
	}
	public function getLabelField($key){
		$name_label = '';
		switch($key){
			default:
			case 'featured_product':
				$name_label = $this->l('Featured Products');
				break;
			case 'special_product':
				$name_label = $this->l('Special Products');
				break;
			case 'new_product':
				$name_label = $this->l('New Products');
				break;
			case 'top_sellers':
				$name_label = $this->l('Best Sellers');
				break;			
		}
		return $name_label;
	}
	public function getContent() {
		$languages = Language::getLanguages(false);
		
		if (Tools::isSubmit('submitModule')) {
			
			if (!Tools::getValue('SNSPRT_NUMDISPLAY') || Tools::getValue('SNSPRT_NUMDISPLAY') <= 0 || !Validate::isInt(Tools::getValue('SNSPRT_NUMDISPLAY')))
				$errors[] = $this->l('Invalid number of products');
			if (!Tools::getValue('SNSPRT_NUMLOAD') || Tools::getValue('SNSPRT_NUMLOAD') <= 0 || !Validate::isInt(Tools::getValue('SNSPRT_NUMLOAD')))
				$errors[] = $this->l('Invalid number of load');
			
			if (!Tools::getValue('SNSPRT_XS')  || ( Tools::getValue('SNSPRT_XS') != 1 && Tools::getValue('SNSPRT_XS') != 2 && Tools::getValue('SNSPRT_XS') != 3 && Tools::getValue('SNSPRT_XS') != 4 && Tools::getValue('SNSPRT_XS') != 6 ) )
				$errors[] = $this->l('Invalid number pre row. You can only set is 1,2,3,4 or 6');
			if (!Tools::getValue('SNSPRT_SM')  || ( Tools::getValue('SNSPRT_SM') != 1 && Tools::getValue('SNSPRT_SM') != 2 && Tools::getValue('SNSPRT_SM') != 3 && Tools::getValue('SNSPRT_SM') != 4 && Tools::getValue('SNSPRT_SM') != 6 ) )
				$errors[] = $this->l('Invalid number pre row. You can only set is 1,2,3,4 or 6');
			if (!Tools::getValue('SNSPRT_MD')  || ( Tools::getValue('SNSPRT_MD') != 1 && Tools::getValue('SNSPRT_MD') != 2 && Tools::getValue('SNSPRT_MD') != 3 && Tools::getValue('SNSPRT_MD') != 4 && Tools::getValue('SNSPRT_MD') != 6 ) )
				$errors[] = $this->l('Invalid number pre row. You can only set is 1,2,3,4 or 6');
			if (!Tools::getValue('SNSPRT_LG')  || ( Tools::getValue('SNSPRT_LG') != 1 && Tools::getValue('SNSPRT_LG') != 2 && Tools::getValue('SNSPRT_LG') != 3 && Tools::getValue('SNSPRT_LG') != 4 && Tools::getValue('SNSPRT_LG') != 6 ) )
				$errors[] = $this->l('Invalid number pre row. You can only set is 1,2,3,4 or 6');
			
			$items = Tools::getValue('items');
			if (!(is_array($items) && count($items) && Configuration::updateValue('SNSPRT_CATEGORY_TABS_ID', (string)implode(',', $items))))
				$errors[] =$this->l('Unable to update settings.');

			if (isset($errors) AND sizeof($errors)) {
				$this->_html .= $this->displayError(implode('<br />', $errors));
			} else {
				$values = array();
				foreach ($languages as $lang) {
					$values['SNSPRT_TITLE'][$lang['id_lang']] = Tools::getValue('SNSPRT_TITLE_'.$lang['id_lang']);
					$values['SNSPRT_PRETEXT'][$lang['id_lang']] = Tools::getValue('SNSPRT_PRETEXT_'.$lang['id_lang']);
					$values['SNSPRT_POSTEXT'][$lang['id_lang']] = Tools::getValue('SNSPRT_POSTEXT_'.$lang['id_lang']);
				}
				Configuration::updateValue('SNSPRT_TITLE', $values['SNSPRT_TITLE'], true);
				Configuration::updateValue('SNSPRT_PRETEXT', $values['SNSPRT_PRETEXT'], true);
				Configuration::updateValue('SNSPRT_POSTEXT', $values['SNSPRT_POSTEXT'], true);

				Configuration::updateValue('SNSPRT_NUMDISPLAY', (int)Tools::getValue('SNSPRT_NUMDISPLAY'));
				Configuration::updateValue('SNSPRT_NUMLOAD', (int)Tools::getValue('SNSPRT_NUMLOAD'));
				Configuration::updateValue('SNSPRT_EFFECT', Tools::getValue('SNSPRT_EFFECT'));
				Configuration::updateValue('SNSPRT_XS', (int)Tools::getValue('SNSPRT_XS'));
				Configuration::updateValue('SNSPRT_SM', (int)Tools::getValue('SNSPRT_SM'));
				Configuration::updateValue('SNSPRT_MD', (int)Tools::getValue('SNSPRT_MD'));
				Configuration::updateValue('SNSPRT_LG', (int)Tools::getValue('SNSPRT_LG'));
				Configuration::updateValue('SNSPRT_CLASSSFX', Tools::getValue('SNSPRT_CLASSSFX'));
				
				$this->_html .= $this->displayConfirmation($this->l('Settings updated'));
			}
			$this->clearCache();
		}
		$this->_html .= $this->renderForm();
		return $this->_html;
	}
	public function getListEffect()
	{
		return array(
			array('id' => 'slideBottom', 'name' => 'slideBottom'),
			array('id' => 'slideLeft', 'name' => 'slideLeft'),
			array('id' => 'slideRight', 'name' => 'slideRight'),
			array('id' => 'bounceIn', 'name' => 'bounceIn'),
			array('id' => 'bounceInRight', 'name' => 'bounceInRight'),
			array('id' => 'zoomIn', 'name' => 'zoomIn'),
			array('id' => 'zoomOut', 'name' => 'zoomOut'),
			array('id' => 'pageTop', 'name' => 'pageTop'),
			array('id' => 'pageBottom', 'name' => 'pageBottom'),
			array('id' => 'pageLeft', 'name' => 'pageLeft'),
			array('id' => 'pageRight', 'name' => 'pageRight'),
			array('id' => 'starwars', 'name' => 'starwars')
		);
	}
	public function getForm() {
		$fields_form = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('General Options'),
					'icon' => 'icon-cogs'
					),

				'input' => array(
		            array(
		                'type' => 'text',
		                'label' => $this->l('Module Title'),
		                'name' => 'SNSPRT_TITLE',
		                'class' => 'fixed-width-xl',
		            	'lang' => true
		            ),
					array(
						'type' => 'text',
						'label' => $this->l('Max. product count per tab'),
						'name' => 'SNSPRT_NUMDISPLAY',
						'class' => 'fixed-width-xs',
						'suffix' => $this->l('products per tab')
						),
					array(
						'type' => 'text',
						'label' => $this->l('Max. product count per load'),
						'name' => 'SNSPRT_NUMLOAD',
						'class' => 'fixed-width-xs',
						'suffix' => $this->l('products per load')
						),
					array(
						'type' => 'select',
						'label' => 'Layout type',
						'name' => 'SNSPRT_EFFECT',
						'options' => array(
							'query' => $this->getListEffect(),
							'id' => 'id',
							'name' => 'name'
						)
					),
					array(
						'type' => 'link_choice',
						'label' => '',
						'name' => 'link',
						'lang' => true,
						),	
					array(
						'label' => $this->l('Screen width > 480px'),
						'name' => 'SNSPRT_XS',
						'type' => 'text', 'class' => 'fixed-width-xs', 'suffix' => $this->l('products per row')
						),
					array(
						'label' => $this->l('Screen width > 768px'),
						'name' => 'SNSPRT_SM',
						'type' => 'text', 'class' => 'fixed-width-xs', 'suffix' => $this->l('products per row')
						),
					array(
						'label' => $this->l('Screen width > 992px'),
						'name' => 'SNSPRT_MD',
						'type' => 'text', 'class' => 'fixed-width-xs', 'suffix' => $this->l('products per row')
						),
					array(
						'label' => $this->l('Screen width > 1200px'),
						'name' => 'SNSPRT_LG',
						'type' => 'text', 'class' => 'fixed-width-xs', 'suffix' => $this->l('products per row')
						),
					),
				'submit' => array(
					'name' => 'submitModule',
					'title' => $this->l('Save')
					)
				),
			);
		$advanceSection = array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Advanced Options'),
					'icon' => 'icon-cogs'
				),
				'input' => array(
		            array(
		                'type' => 'text',
		                'label' => $this->l('Module Class Suffix'),
		                'name' => 'SNSPRT_CLASSSFX',
		                'hint' => $this->l('A suffix to be applied to the CSS class of the module. This allows for individual module styling.'),
		                'class' => 'fixed-width-xl'
		            ),
		            array(
		                'type' => 'textarea',
		                'label' => $this->l('Pre-text'),
		                'name' => 'SNSPRT_PRETEXT',
		                'hint' => $this->l('Intro text of module.'),
		            	'lang' => true,
		            	'autoload_rte' => true
		            ),
		            array(
		                'type' => 'textarea',
		                'label' => $this->l('Post-text'),
		                'name' => 'SNSPRT_POSTEXT',
		                'hint' => $this->l('Footer text of module.'),
		            	'lang' => true,
		            	'autoload_rte' => true
		            )
				),
				'submit' => array(
					'name' => 'submitModule',
					'title' => $this->l('Save')
				)
			)
		);
		if (Shop::isFeatureActive()) {
			$fields_form['form']['description'] = $this->l('The modifications will be applied to').' '.(Shop::getContext() == Shop::CONTEXT_SHOP ? $this->l('shop').' '.$this->context->shop->name : $this->l('all shops'));
			$advanceSection['form']['description'] = $this->l('The modifications will be applied to').' '.(Shop::getContext() == Shop::CONTEXT_SHOP ? $this->l('shop').' '.$this->context->shop->name : $this->l('all shops'));
		}
		return array($fields_form, $advanceSection);
	}
	public function renderForm() {
		
		$helper = new HelperForm();
		$helper->show_toolbar = false;
		$helper->table =  $this->table;
		$lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));
		$helper->module = $this;
		$helper->default_form_language = $lang->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
		$this->fields_form = array();
		$helper->module = $this;
		$helper->identifier = $this->identifier;	
		$helper->submit_action = 'submitSNSFacebook';	
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');
		$helper->tpl_vars = array(
			'uri' => $this->getPathUri(),
			'fields_value' => $this->getConfigFieldsValues(),
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id,
			'choices' => $this->renderChoicesSelect(),
			'selected_links' => $this->makeMenuOption(),
			);
		return $helper->generateForm($this->getForm());
	}
	public function getConfigFieldsValues() {
		$values = array();
		
		$languages = Language::getLanguages(false);
		
		foreach ($languages as $lang) {
			$values['SNSPRT_TITLE'][$lang['id_lang']] = Tools::getValue('SNSPRT_TITLE_'.$lang['id_lang'], Configuration::get('SNSPRT_TITLE', $lang['id_lang']));
			$values['SNSPRT_PRETEXT'][$lang['id_lang']] = Tools::getValue('SNSPRT_PRETEXT_'.$lang['id_lang'], Configuration::get('SNSPRT_PRETEXT', $lang['id_lang']));
			$values['SNSPRT_POSTEXT'][$lang['id_lang']] = Tools::getValue('SNSPRT_POSTEXT_'.$lang['id_lang'], Configuration::get('SNSPRT_POSTEXT', $lang['id_lang']));
		}

		$values['SNSPRT_NUMDISPLAY'] = Tools::getValue('SNSPRT_NUMDISPLAY', Configuration::get('SNSPRT_NUMDISPLAY'));
		$values['SNSPRT_NUMLOAD'] = Tools::getValue('SNSPRT_NUMLOAD', Configuration::get('SNSPRT_NUMLOAD'));
		$values['SNSPRT_EFFECT'] = Tools::getValue('SNSPRT_EFFECT', Configuration::get('SNSPRT_EFFECT'));
		$values['SNSPRT_XS'] = Tools::getValue('SNSPRT_XS', Configuration::get('SNSPRT_XS'));
		$values['SNSPRT_SM'] = Tools::getValue('SNSPRT_SM', Configuration::get('SNSPRT_SM'));
		$values['SNSPRT_MD'] = Tools::getValue('SNSPRT_MD', Configuration::get('SNSPRT_MD'));
		$values['SNSPRT_LG'] = Tools::getValue('SNSPRT_LG', Configuration::get('SNSPRT_LG'));
		$values['SNSPRT_CLASSSFX'] = Tools::getValue('SNSPRT_CLASSSFX', Configuration::get('SNSPRT_CLASSSFX'));

		return $values;
	}
	public function hookDisplayHeader($params) {
		//Configuration::updateValue('PS_NB_DAYS_NEW_PRODUCT', 57);
		
		if (!isset($this->context->controller->php_self) || $this->context->controller->php_self != 'index')
			return;
		$this->context->controller->addJS($this->_path . 'js/snsproducttabs.js');
		$this->context->controller->addCSS($this->_path . 'css/style.css');
	}
	public function getVarAssign() {
		$context = Context::getContext();
		$id_lang = (int) $context->language->id;
		$vars = array();
		$xs = 12 / Configuration::get('SNSPRT_XS');
		$sm = 12 / Configuration::get('SNSPRT_SM');
		$md = 12 / Configuration::get('SNSPRT_MD');
		$lg = 12 / Configuration::get('SNSPRT_LG');
		$vars['item_class'] = 'col-xs-'.$xs.' col-sm-'.$sm.' col-md-'.$md.' col-lg-'.$lg.' col-phone-12';
		
		$lang_fields = array('SNSPRT_TITLE', 'SNSPRT_PRETEXT', 'SNSPRT_POSTEXT');
		$fields = array('SNSPRT_NUMDISPLAY', 'SNSPRT_NUMLOAD', 'SNSPRT_EFFECT', 'SNSPRT_XS', 'SNSPRT_SM', 'SNSPRT_MD', 'SNSPRT_LG', 'SNSPRT_CLASSSFX');

		foreach($fields as $field)
			$vars[$field] = Configuration::get($field);
		
		foreach($lang_fields as $field) 
		{
			if(is_bool(Configuration::get($field, $id_lang)))
				$vars[$field] = Configuration::get($field, Configuration::get('PS_LANG_DEFAULT'));
			else
				$vars[$field] = Configuration::get($field, $id_lang);
		}
		
		$vars['xs'] = $xs;
		$vars['sm'] = $sm;
		$vars['md'] = $md;
		$vars['lg'] = $lg;
		
		return $vars;
	}
	public function displaySNSProductTabs()
	{
		$context = Context::getContext();
		$id_lang = (int) $context->language->id;
		
		$cache_id = $this->getCacheId('snsproducttabs');
		if (!$this->isCached('snsproducttabs.tpl', $cache_id))
		{
			$tabs = $this->_getData();
			if (empty($tabs))
				return;
			$context->smarty->assign(array('tabs' => $tabs));
			$context->smarty->assign($this->getVarAssign());
			$context->smarty->assign(array('homeSize' => Image::getSize(ImageType::getFormatedName('home'))));
		}
		
		return $this->display(__FILE__, 'snsproducttabs.tpl', $cache_id);
	}
	public function hookDisplayHome() {
		return $this->displaySNSProductTabs();
	}
	public function _processAjaxCall()
	{
		$context = Context::getContext();
		$is_ajax =	Tools::getValue('is_ajax');
		$module_name = Tools::getValue('module_name');
		if($is_ajax && $module_name == $this->name ) {
			$ajax_start = Tools::getValue('ajax_start');
			$categoryid	 = Tools::getValue('categoryid');
			$data_type = Tools::getValue('data_type');
			$products = $this->_getProductInfor($categoryid,$data_type);
			
			$context->smarty->assign($this->getVarAssign());
			$context->smarty->assign(
				array(
					'ajax_start' => Tools::getValue('ajax_start'),
					'products' => $products,
					'homeSize' => Image::getSize(ImageType::getFormatedName('home'))
				)
			);
			
            $product_list = $this->display(__FILE__, 'items.tpl');
			//$product_list = $context->smarty->fetch(_PS_THEME_DIR_.'product-tabs.tpl');
			$vars = array(
				'productList' => $product_list
			);
			die( Tools::jsonEncode($vars));
		}
	}
	public function clearCache() {
		$this->_clearCache('snsproducttabs.tpl');
	}
	public function hookAddProduct($params) {
		$this->clearCache();
	}
	public function hookUpdateProduct($params) {
		$this->clearCache();
	}
	public function hookDeleteProduct($params) {
		$this->clearCache();
	}
}
